Mesa (master): i965/gen9: Setup MCS for compressed texture surfaces

Topi Pohjolainen tpohjola at kemper.freedesktop.org
Thu May 12 17:19:26 UTC 2016


Module: Mesa
Branch: master
Commit: 683dda00830b6c5f450d4ccbc95b108fe3f091b0
URL:    http://cgit.freedesktop.org/mesa/mesa/commit/?id=683dda00830b6c5f450d4ccbc95b108fe3f091b0

Author: Topi Pohjolainen <topi.pohjolainen at intel.com>
Date:   Mon Feb  8 18:00:31 2016 +0200

i965/gen9: Setup MCS for compressed texture surfaces

Signed-off-by: Topi Pohjolainen <topi.pohjolainen at intel.com>
Reviewed-by: Ben Widawsky <ben at bwidawsk.net>

---

 src/mesa/drivers/dri/i965/gen8_surface_state.c | 9 +++++----
 1 file changed, 5 insertions(+), 4 deletions(-)

diff --git a/src/mesa/drivers/dri/i965/gen8_surface_state.c b/src/mesa/drivers/dri/i965/gen8_surface_state.c
index 4b9896f..b846284 100644
--- a/src/mesa/drivers/dri/i965/gen8_surface_state.c
+++ b/src/mesa/drivers/dri/i965/gen8_surface_state.c
@@ -249,11 +249,12 @@ gen8_emit_texture_surface_state(struct brw_context *brw,
       pitch = mt->pitch;
    }
 
    /* The MCS is not uploaded for single-sampled surfaces because the color
     * buffer should always have been resolved before it is used as a texture
     * so there is no need for it.
     */
-   if (mt->num_samples <= 1) {
+   if (mt->num_samples <= 1 && aux_mode != GEN9_SURFACE_AUX_MODE_CCS_E) {
       aux_mt = NULL;
       aux_mode = GEN8_SURFACE_AUX_MODE_NONE;
    }
@@ -249,11 +249,12 @@ gen8_emit_texture_surface_state(struct brw_context *brw,
    }
 
-   /* The MCS is not uploaded for single-sampled surfaces because the color
-    * buffer should always have been resolved before it is used as a texture
-    * so there is no need for it.
+   /* Prior to Gen9, MCS is not uploaded for single-sampled surfaces because
+    * the color buffer should always have been resolved before it is used as
+    * a texture so there is no need for it. On Gen9 it will be uploaded when
+    * the surface is losslessly compressed (CCS_E).
     */




More information about the mesa-commit mailing list